summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmmovecommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmmovecommand.h')
-rw-r--r--kpovmodeler/pmmovecommand.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpovmodeler/pmmovecommand.h b/kpovmodeler/pmmovecommand.h
index 5aac246d..188d721c 100644
--- a/kpovmodeler/pmmovecommand.h
+++ b/kpovmodeler/pmmovecommand.h
@@ -39,23 +39,23 @@ public:
/**
* Command that moves one PMObject.
*
* The object obj will be inserted as child of parent after
* the object after.
*
* If after is 0, the object becomes the first child.
*/
- PMMoveCommand( PMObject* obj, PMObject* parent, PMObject* after );
+ PMMoveCommand( PMObject* obj, PMObject* tqparent, PMObject* after );
/**
* Command that moves a list of new PMObjects.
* The objects don't have to be siblings of each other.
*
* The object in the list will be inserted as children of parent after
* the object after.
*
- * If after is 0, the objects will be inserted as first children.
+ * If after is 0, the objects will be inserted as first tqchildren.
*/
- PMMoveCommand( const PMObjectList& list, PMObject* parent, PMObject* after );
+ PMMoveCommand( const PMObjectList& list, PMObject* tqparent, PMObject* after );
/**
* Deletes the command.
*/
@@ -39,23 +39,23 @@ public:
* Command that moves one PMObject.
*
- * The object obj will be inserted as child of parent after
+ * The object obj will be inserted as child of tqparent after
* the object after.
*
@@ -39,23 +39,23 @@ public:
* The objects don't have to be siblings of each other.
*
- * The object in the list will be inserted as children of parent after
+ * The object in the list will be inserted as tqchildren of tqparent after
* the object after.
*